@@ -4,4 +4,6 @@ from .phs_grammar  import parsePHS
 from .phs_xml import phenoscriptToXML
 from .phs_xmlTranslateTerms import xmlTranslateTerms, xmlTranslateTermsMeta
 from .snips_makeFromYaml import make_vscodeSnips
-from .snips_fun import printUniqueIRIs
\ No newline at end of file
+from .snips_fun import printUniqueIRIs
+from .nl_owlToMd_fun import owlToNLgraph, NLgraphToMarkdown
+from .utils import download_ontologies_from_yaml
\ No newline at end of file
